{ Marco Cantu' (author of Master Delphi x and Delphi Developers Handbook has   }
{ released an excellent run-time object inspector tool as freeware.  It can be }
{ found in the Delphi Developers Handbook (highly recommended) and on his web  }
{ site at http://www.marcocantu.com.  If you have this installed, you can      }
{ enable the following define (remove the period) to use it in the demo.       }
{ It is for Delphi 3 only, but I think he has a beta for Delphi 2.             }
{.$DEFINE DFS_RUN_TIME_DEBUGGER}

unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  {$IFDEF DFS_RUN_TIME_DEBUGGER}
  DdhObjDb,
  {$ENDIF}
  StdCtrls, Spin, GradForm;

type
  TForm1 = class(TGradientForm)
    edGradientColors: TSpinEdit;
    Label1: TLabel;
    Label2: TLabel;
    Edit1: TEdit;
    ColorDialog1: TColorDialog;
    Button1: TButton;
    Button2: TButton;
    Button3: TButton;
    Label3: TLabel;
    cbxDrawGrad: TComboBox;
    procedure FormCreate(Sender: TObject);
    procedure edGradientColorsChange(Sender: TObject);
    procedure Edit1Change(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure cbxDrawGradChange(Sender: TObject);
  private
  public
    procedure Form1CaptionPaint(Sender: TObject; const Canvas: TCanvas; var R: TRect);
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

procedure TForm1.FormCreate(Sender: TObject);
begin
  {$IFDEF DFS_RUN_TIME_DEBUGGER}
  TDdhObjectDebugger.Create(Self);
  {$ENDIF}
  OnCaptionPaint := Form1CaptionPaint;
  with edGradientColors do begin
    Value := GradientColors;
    MinValue := MIN_GRADIENT_COLORS;
    MaxValue := MAX_GRADIENT_COLORS;
  end;
  cbxDrawGrad.ItemIndex := ord(PaintGradient);
  Edit1.Text := Caption;
end;

procedure TForm1.edGradientColorsChange(Sender: TObject);
begin
  if (edGradientColors.Value >= MIN_GRADIENT_COLORS) and
     (edGradientColors.Value <= MAX_GRADIENT_COLORS) then
    GradientColors := edGradientColors.Value;
end;

procedure TForm1.Edit1Change(Sender: TObject);
begin
  Caption := Edit1.Text;
end;

procedure TForm1.Form1CaptionPaint(Sender: TObject; const Canvas: TCanvas; var R: TRect);
var
  MyRect: TRect;
begin
  Canvas.Brush.Color := clRed; // Set the canvas' brush color to something nice.
  MyRect := R; // A rectangle for keeping track of stuff.
  with MyRect do Right := Left + (Bottom-Top); // Make it square, the size of the
                                               // available height.
  InflateRect(MyRect, -2, -2); // Give it a small margin.
  Canvas.FillRect(MyRect); // Paint a red square
  InflateRect(MyRect, -2, -2); // Make it a little smaller.
  Canvas.Brush.Color := clBlue; // Change the color to something else.
  with MyRect do
    Canvas.Ellipse(Left, Top, Right, Bottom); // Make a circle inside the square.
  // We need to update the size of the rectangle passed in so that it does not contain
  // the rectangle we just drew in.  The caption text still has to be drawn and it needs
  // to know what rectangle is left for it to occupy.  In this case, we drew in a square
  // on the left side of the caption, so we just increment the Left value by the area
  // we used.
  Inc(R.Left, (R.Bottom-R.Top));
end;


procedure TForm1.Button1Click(Sender: TObject);
begin
  with (Sender as TButton) do
    if ColorDialog1.Execute then
      case Tag of
        0: GradientStartColor := ColorDialog1.Color;
        1: GradientStopColor := ColorDialog1.Color;
        2: CaptionTextColor := ColorDialog1.Color;
      end;
end;

procedure TForm1.cbxDrawGradChange(Sender: TObject);
begin
  case cbxDrawGrad.ItemIndex of
    0: PaintGradient := gfpAlways;
    1: PaintGradient := gfpActive;
    2: PaintGradient := gfpNever;
  end;
end;

end.
